@@ -32,8 +32,8 @@ from time import sleep
 
 import numpy as np
 import gdal
-from py_tools_ds.geo.projection import EPSG2WKT, WKT2EPSG, proj4_to_WKT
-from py_tools_ds.geo.coord_trafo import get_proj4info, proj4_to_dict, transform_coordArray, transform_any_prj
+from py_tools_ds.geo.projection import EPSG2WKT, WKT2EPSG, proj4_to_WKT, proj4_to_dict
+from py_tools_ds.geo.coord_trafo import get_proj4info, transform_coordArray, transform_any_prj
 from py_tools_ds.geo.coord_calc import corner_coord_to_minmax, get_corner_coordinates
 from py_tools_ds.geo.coord_grid import find_nearest
 from py_tools_ds.io.raster.writer import write_numpy_to_image
